Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(805)

Unified Diff: pkg/analyzer_experimental/lib/src/error_formatter.dart

Issue 15853005: Change the cmd-line output for warnings from foo.dart:line:col to foo.dart, line x, col y. (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « editor/tools/plugins/com.google.dart.command.analyze/src/com/google/dart/command/analyze/ErrorFormatter.java ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/analyzer_experimental/lib/src/error_formatter.dart
===================================================================
--- pkg/analyzer_experimental/lib/src/error_formatter.dart (revision 23419)
+++ pkg/analyzer_experimental/lib/src/error_formatter.dart (working copy)
@@ -124,18 +124,10 @@
out.write('|');
out.writeln(escapePipe(error.message));
} else {
- // [warning] 'foo' is not a method or function (/Users/devoncarew/temp/foo.dart:-1:-1)
- out.write('[');
- out.write(severity.displayName);
- out.write('] ');
- out.write(error.message);
- out.write(' (');
- out.write(source.fullName);
- out.write(':');
- out.write(location.lineNumber);
- out.write(':');
- out.write(location.columnNumber);
- out.writeln(')');
+ // [warning] 'foo' is not a... (/Users/.../tmp/foo.dart, line 1, col 2)
+ out.write('[${severity.displayName}] ${error.message} ');
+ out.write('(${source.fullName}');
+ out.write(', line ${location.lineNumber}, col ${location.columnNumber})');
}
}
« no previous file with comments | « editor/tools/plugins/com.google.dart.command.analyze/src/com/google/dart/command/analyze/ErrorFormatter.java ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698